# <span class="badge package-variant-dataquery"></span> bigquery

## Objects

 * <span class="badge object-type-class"></span> [Dataquery](./object-Dataquery.md)
 * <span class="badge object-type-enum"></span> [EditorMode](./object-EditorMode.md)
 * <span class="badge object-type-enum"></span> [OrderByDirection](./object-OrderByDirection.md)
 * <span class="badge object-type-enum"></span> [QueryEditorExpressionType](./object-QueryEditorExpressionType.md)
 * <span class="badge object-type-class"></span> [QueryEditorFunctionExpression](./object-QueryEditorFunctionExpression.md)
 * <span class="badge object-type-class"></span> [QueryEditorFunctionParameterExpression](./object-QueryEditorFunctionParameterExpression.md)
 * <span class="badge object-type-class"></span> [QueryEditorGroupByExpression](./object-QueryEditorGroupByExpression.md)
 * <span class="badge object-type-class"></span> [QueryEditorProperty](./object-QueryEditorProperty.md)
 * <span class="badge object-type-class"></span> [QueryEditorPropertyExpression](./object-QueryEditorPropertyExpression.md)
 * <span class="badge object-type-enum"></span> [QueryEditorPropertyType](./object-QueryEditorPropertyType.md)
 * <span class="badge object-type-enum"></span> [QueryFormat](./object-QueryFormat.md)
 * <span class="badge object-type-enum"></span> [QueryPriority](./object-QueryPriority.md)
 * <span class="badge object-type-class"></span> [SQLExpression](./object-SQLExpression.md)
## Builders

 * <span class="badge builder"></span> [Dataquery](./builder-Dataquery.md)
 * <span class="badge builder"></span> [QueryEditorFunctionExpression](./builder-QueryEditorFunctionExpression.md)
 * <span class="badge builder"></span> [QueryEditorFunctionParameterExpression](./builder-QueryEditorFunctionParameterExpression.md)
 * <span class="badge builder"></span> [QueryEditorGroupByExpression](./builder-QueryEditorGroupByExpression.md)
 * <span class="badge builder"></span> [QueryEditorProperty](./builder-QueryEditorProperty.md)
 * <span class="badge builder"></span> [QueryEditorPropertyExpression](./builder-QueryEditorPropertyExpression.md)
 * <span class="badge builder"></span> [SQLExpression](./builder-SQLExpression.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to grafana-bigquery-datasource data queries.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.DataqueryConfig
```

